@@ -13,7 +13,8 @@ class ClientModel(ABC):
     '''
     def __init__(self, _dict=None, author=None, plugin_version=1, heartbeat_required="true", date_created=None, match_list=None, match_case="insensitive"):
         self.dict = {}
-        self.author = author
+        if not author:
+            self.author = "TechStyleOS"
         self.__setitem__('author', self.author)
         self.plugin_version = plugin_version
         self.__setitem__('plugin_version', self.plugin_version)
